import { callCloudFunction } from '../cloud'
import type { TurtleSoupGame, GameResult } from '@/types/game'

/**
 * 获取游戏数据
 * @param gameId 游戏ID
 * @param role 用户角色
 */
export function getGameData(gameId: string, role: string) {
  return callCloudFunction<{ game: TurtleSoupGame }>('getGameData', { gameId, role })
}

/**
 * 提交问题
 * @param gameId 游戏ID
 * @param content 问题内容
 */
export function submitQuestion(gameId: string, content: string) {
  return callCloudFunction<{ questionId: string }>('submitQuestion', { gameId, content })
}

/**
 * 回答问题
 * @param questionId 问题ID
 * @param answer 答案
 */
export function answerQuestion(questionId: string, answer: string) {
  return callCloudFunction<{ success: boolean }>('answerQuestion', { questionId, answer })
}

/**
 * 公开提示
 * @param gameId 游戏ID
 * @param hintIndex 提示索引
 */
export function revealHint(gameId: string, hintIndex: number) {
  return callCloudFunction<{ success: boolean }>('revealHint', { gameId, hintIndex })
}

/**
 * 结束游戏
 * @param gameId 游戏ID
 * @param result 游戏结果
 */
export function endGame(gameId: string, result: { solved: boolean; solvedBy?: string }) {
  return callCloudFunction<{ gameResult: GameResult }>('endGame', { gameId, result })
}