import { callCloudFunction } from '../cloud'
import type { Room, RoomSettings } from '@/types/room'

/**
 * 创建游戏房间
 * @param gameType 游戏类型
 * @param settings 房间设置
 */
export function createRoom(gameType: string, settings: RoomSettings) {
  return callCloudFunction<{ roomId: string; roomCode: string }>('createRoom', {
    gameType,
    settings
  })
}

/**
 * 加入游戏房间
 * @param roomCode 房间码
 */
export function joinRoom(roomCode: string) {
  return callCloudFunction<{ room: Room }>('joinRoom', { roomCode })
}

/**
 * 获取房间详情
 * @param roomId 房间ID
 */
export function getRoomDetail(roomId: string) {
  return callCloudFunction<{ room: Room }>('getRoomDetail', { roomId })
}

/**
 * 开始游戏
 * @param roomId 房间ID
 */
export function startGame(roomId: string) {
  return callCloudFunction<{ gameId: string }>('startGame', { roomId })
}

/**
 * 离开房间
 * @param roomId 房间ID
 */
export function leaveRoom(roomId: string) {
  return callCloudFunction<{ success: boolean }>('leaveRoom', { roomId })
}