// 房间角色枚举
export enum RoomRole {
    HOST = 'host',
    PLAYER = 'player'
  }
  
  // 房间状态枚举
  export enum RoomStatus {
    WAITING = 'waiting',   // 等待中
    PLAYING = 'playing',   // 游戏中
    ENDED = 'ended'        // 已结束
  }
  
  // 房间成员模型
  export interface RoomMember {
    id: string;            // 用户ID
    role: RoomRole;        // 主持人/玩家
    nickname: string;      // 昵称
    avatarUrl: string;     // 头像
    joinTime: Date;        // 加入时间
    isReady: boolean;      // 准备状态
  }
  
  // 房间模型
  export interface Room {
    id: string;            // 房间ID
    roomCode: string;      // 6位房间码
    gameType: string;      // 游戏类型
    gameId: string;        // 游戏内容ID
    hostId: string;        // 主持人ID
    createdAt: Date;       // 创建时间
    status: RoomStatus;    // 房间状态
    settings: RoomSettings; // 房间设置
    location?: RoomLocation; // 可选位置信息
    players: RoomMember[]; // 玩家列表
  }
  
  // 房间设置
  export interface RoomSettings {
    maxPlayers: number;
    isPublic: boolean;
    difficulty: string;
    hintRevealMode: string; // 自动/手动
  }
  
  // 房间位置
  export interface RoomLocation {
    latitude: number;
    longitude: number;
    name?: string;       // 位置名称
  }